package com.hedera.mirror.importer.repository;

/*-
 * ‌
 * Hedera Mirror Node
 * ​
 * Copyright (C) 2019 - 2022 Hedera Hashgraph, LLC
 * ​
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ‍
 */

import static org.assertj.core.api.Assertions.assertThat;

import lombok.RequiredArgsConstructor;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;

@RequiredArgsConstructor(onConstructor = @__(@Autowired))
class EthereumTransactionRepositoryTest extends AbstractRepositoryTest {

    private final EthereumTransactionRepository ethereumTransactionRepository;

    @Test
    void prune() {
        domainBuilder.ethereumTransaction(true).persist();
        var ethereumTransaction2 = domainBuilder.ethereumTransaction(false).persist();
        var ethereumTransaction3 = domainBuilder.ethereumTransaction(true).persist();

        ethereumTransactionRepository.prune(ethereumTransaction2.getConsensusTimestamp());

        assertThat(ethereumTransactionRepository.findAll()).containsExactly(ethereumTransaction3);
    }

    @Test
    void saveInitCode() {
        var ethereumTransaction = domainBuilder.ethereumTransaction(true).persist();
        assertThat(ethereumTransactionRepository.findById(ethereumTransaction.getId()))
                .get()
                .isEqualTo(ethereumTransaction);
    }

    @Test
    void saveFileId() {
        var ethereumTransaction = domainBuilder.ethereumTransaction(false).persist();
        assertThat(ethereumTransactionRepository.findById(ethereumTransaction.getId()))
                .get()
                .isEqualTo(ethereumTransaction);
    }
}
