package com.hedera.mirror.test.e2e.acceptance.config;

/*-
 * ‌
 * Hedera Mirror Node
 * ​
 * Copyright (C) 2019 - 2022 Hedera Hashgraph, LLC
 * ​
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ‍
 */

import com.google.common.base.Throwables;
import java.time.Duration;
import java.util.Set;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import lombok.Data;
import org.hibernate.validator.constraints.time.DurationMin;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;
import org.springframework.validation.annotation.Validated;

@Component
@ConfigurationProperties(prefix = "hedera.mirror.test.acceptance.rest")
@Data
@Validated
public class RestPollingProperties {

    @NotBlank
    private String baseUrl;

    @Min(1)
    @Max(60)
    private int maxAttempts = 10;

    @NotNull
    @DurationMin(millis = 500L)
    private Duration maxBackoff = Duration.ofSeconds(4L);

    @NotNull
    @DurationMin(millis = 100L)
    private Duration minBackoff = Duration.ofMillis(500L);

    @NotNull
    private Set<Class> retryableExceptions = Set.of(Exception.class);

    public boolean shouldRetry(Throwable t) {
        return retryableExceptions.stream()
                .anyMatch(ex -> ex.isInstance(t) || ex.isInstance(Throwables.getRootCause(t)));
    }
}
